# Images for frontpage

This contain images for the frontpage of nbviewer. 

at most thoses images will be show with a size of 360x225 (W x H), aspect ratio
(W/H) of 1.6.  As they might be show on retina display, consider using a double
resolution.  Resizing will be handled by browser, so to avoid artifact images
shoudl be of size multiple of maximum size ie (720 width) by (450 height),
preferentially in png, and passed to png crusher as the number of request for
thoses images will be heigh.


